@@ -74,14 +74,26 @@ class Column(object):
 
     instance_counter = 0
 
-    def __init__(self, primary_key=False, partition_key=False, index=False, db_field=None, default=None, required=True, clustering_order=None):
+    def __init__(self,
+                 primary_key=False,
+                 partition_key=False,
+                 index=False,
+                 db_field=None,
+                 default=None,
+                 required=False,
+                 clustering_order=None):
         """
         :param primary_key: bool flag, indicates this column is a primary key. The first primary key defined
-        on a model is the partition key, all others are cluster keys
+            on a model is the partition key (unless partition keys are set), all others are cluster keys
+        :param partition_key: indicates that this column should be the partition key, defining
+            more than one partition key column creates a compound partition key
         :param index: bool flag, indicates an index should be created for this column
         :param db_field: the fieldname this field will map to in the database
         :param default: the default value, can be a value or a callable (no args)
-        :param required: boolean, is the field required?
+        :param required: boolean, is the field required? Model validation will raise and
+            exception if required is set to True and there is a None value assigned
+        :param clustering_order: only applicable on clustering keys (primary keys that are not partition keys)
+            determines the order that the clustering keys are sorted on disk
         """
         self.partition_key = partition_key
         self.primary_key = partition_key or primary_key
@@ -224,9 +236,6 @@ class Integer(Column):
 class DateTime(Column):
     db_type = 'timestamp'
 
-    def __init__(self, **kwargs):
-        super(DateTime, self).__init__(**kwargs)
-
     def to_python(self, value):
         if isinstance(value, datetime):
             return value
@@ -253,8 +262,6 @@ class DateTime(Column):
 class Date(Column):
     db_type = 'timestamp'
 
-    def __init__(self, **kwargs):
-        super(Date, self).__init__(**kwargs)
 
     def to_python(self, value):
         if isinstance(value, datetime):
@@ -282,9 +289,6 @@ class UUID(Column):
 
     re_uuid = re.compile(r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}')
 
-    def __init__(self, default=lambda:uuid4(), **kwargs):
-        super(UUID, self).__init__(default=default, **kwargs)
-
     def validate(self, value):
         val = super(UUID, self).validate(value)
         if val is None: return
@@ -300,6 +304,8 @@ class UUID(Column):
     def to_database(self, value):
         return self.validate(value)
 
+from uuid import UUID as pyUUID, getnode
+
 class TimeUUID(UUID):
     """
     UUID containing timestamp
@@ -307,9 +313,46 @@ class TimeUUID(UUID):
 
     db_type = 'timeuuid'
 
-    def __init__(self, **kwargs):
-        kwargs.setdefault('default', lambda: uuid1())
-        super(TimeUUID, self).__init__(**kwargs)
+    @classmethod
+    def from_datetime(self, dt):
+        """
+        generates a UUID for a given datetime
+
+        :param dt: datetime
+        :type dt: datetime
+        :return:
+        """
+        global _last_timestamp
+
+        epoch = datetime(1970, 1, 1, tzinfo=dt.tzinfo)
+
+        offset = 0
+        if epoch.tzinfo:
+            offset_delta = epoch.tzinfo.utcoffset(epoch)
+            offset = offset_delta.days*24*3600 + offset_delta.seconds
+
+        timestamp = (dt  - epoch).total_seconds() - offset
+
+        node = None
+        clock_seq = None
+
+        nanoseconds = int(timestamp * 1e9)
+        timestamp = int(nanoseconds // 100) + 0x01b21dd213814000L
+
+        if clock_seq is None:
+            import random
+            clock_seq = random.randrange(1 << 14L)  # instead of stable storage
+        time_low = timestamp & 0xffffffffL
+        time_mid = (timestamp >> 32L) & 0xffffL
+        time_hi_version = (timestamp >> 48L) & 0x0fffL
+        clock_seq_low = clock_seq & 0xffL
+        clock_seq_hi_variant = (clock_seq >> 8L) & 0x3fL
+        if node is None:
+            node = getnode()
+        return pyUUID(fields=(time_low, time_mid, time_hi_version,
+                            clock_seq_hi_variant, clock_seq_low, node), version=1)
+
+
 
 class Boolean(Column):
     db_type = 'boolean'
@@ -325,6 +368,7 @@ class Boolean(Column):
     def to_database(self, value):
         return self.Quoter(bool(value))
 
+
 class Float(Column):
     db_type = 'double'
 
