@@ -3,6 +3,8 @@ from datetime import datetime, timedelta
 from datetime import date
 from datetime import tzinfo
 from decimal import Decimal as D
+from unittest import TestCase
+from uuid import uuid4, uuid1
 from cqlengine import ValidationError
 
 from cqlengine.tests.base import BaseCassEngTestCase
@@ -119,7 +121,7 @@ class TestDecimal(BaseCassEngTestCase):
 class TestTimeUUID(BaseCassEngTestCase):
     class TimeUUIDTest(Model):
         test_id = Integer(primary_key=True)
-        timeuuid = TimeUUID()
+        timeuuid = TimeUUID(default=uuid1())
 
     @classmethod
     def setUpClass(cls):
@@ -132,6 +134,10 @@ class TestTimeUUID(BaseCassEngTestCase):
         delete_table(cls.TimeUUIDTest)
 
     def test_timeuuid_io(self):
+        """
+        ensures that
+        :return:
+        """
         t0 = self.TimeUUIDTest.create(test_id=0)
         t1 = self.TimeUUIDTest.get(test_id=0)
 
@@ -139,8 +145,8 @@ class TestTimeUUID(BaseCassEngTestCase):
 
 class TestInteger(BaseCassEngTestCase):
     class IntegerTest(Model):
-        test_id = UUID(primary_key=True)
-        value   = Integer(default=0)
+        test_id = UUID(primary_key=True, default=lambda:uuid4())
+        value   = Integer(default=0, required=True)
 
     def test_default_zero_fields_validate(self):
         """ Tests that integer columns with a default value of 0 validate """
@@ -180,7 +186,7 @@ class TestText(BaseCassEngTestCase):
         Text().validate(bytearray('bytearray'))
 
         with self.assertRaises(ValidationError):
-            Text().validate(None)
+            Text(required=True).validate(None)
 
         with self.assertRaises(ValidationError):
             Text().validate(5)
@@ -190,13 +196,27 @@ class TestText(BaseCassEngTestCase):
 
 
 
+class TestExtraFieldsRaiseException(BaseCassEngTestCase):
+    class TestModel(Model):
+        id = UUID(primary_key=True, default=uuid4)
+
+    def test_extra_field(self):
+        with self.assertRaises(ValidationError):
+            self.TestModel.create(bacon=5000)
 
 
+class TestTimeUUIDFromDatetime(TestCase):
+    def test_conversion_specific_date(self):
+        dt = datetime(1981, 7, 11, microsecond=555000)
 
+        uuid = TimeUUID.from_datetime(dt)
 
+        from uuid import UUID
+        assert isinstance(uuid, UUID)
 
+        ts = (uuid.time - 0x01b21dd213814000) / 1e7 # back to a timestamp
+        new_dt = datetime.utcfromtimestamp(ts)
 
-
-
-
+        # checks that we created a UUID1 with the proper timestamp
+        assert new_dt == dt
 
